# -*- coding: utf-8 -*-

# django-po2xls
# po2xls/management/commands/po2xls.py

from __future__ import unicode_literals

from django.core.management.base import BaseCommand
from django.conf import settings

from rosetta.poutil import find_pos

from po2xls.utils import PoToXls


class Command(BaseCommand):
    """
    Convert project translation files to excel.
    """

    ALL = "all"

    def add_arguments(self, parser):

        parser.add_argument("--language", "-l", dest="language", help="Language", default=self.ALL)
        parser.add_argument("--quiet", "-q", dest="quiet", help="Be quiet", default=False, action="store_true")

    def handle(self, *args, **kwargs):

        language = kwargs.pop("language")

        if all([language == self.ALL, settings.LANGUAGES, ]):
            for language in list(dict(settings.LANGUAGES).keys()):
                self.convert(language=language, **kwargs)
        else:
            self.convert(language=language, **kwargs)

    def convert(self, language, *args, **kwargs):
        """
        Run converter.
        Args:
            language: (unicode) language code.
        """

        for f in find_pos(language):
            PoToXls(src=f, **kwargs).convert()



# -*- coding: utf-8 -*-

# django-po2xls
# po2xls/utils.py

from __future__ import unicode_literals
import sys
import os
import logging

import polib
import xlwt


__all__ = [
    "PoToXls",
]


class PoToXls(object):

    logger = logging.getLogger(__name__)

    headers = {
        "strings": [
            "msgid",
            "msgstr",
        ],
        "metadata": [
            "key",
            "value",
        ],
    }

    def __init__(self, src, *args, **kwargs):
        """
        Init conversion.
        Args:
            src: (unicode or string) path to ".po" file.
        """
        self.quiet = kwargs.pop("quiet", False)

        if os.path.exists(src):
            self.src = src
        else:
            if not self.quiet:
                sys.stderr.write("ERROR: File '{src}' does not exists.".format(**{"src": src, }))
            self.logger.error("ERROR: File '{src}' does not exists.".format(**{"src": src, }))
            sys.exit(-1)

        self.po = polib.pofile(self.src)
        self.result = xlwt.Workbook(encoding="utf-8")

    def header(self, sheet, name):
        """
        Write sheet header.
        Args:
            sheet: (xlwt.Worksheet.Worksheet) instance of xlwt sheet.
            name: (unicode) name of sheet.
        """

        header = sheet.row(0)
        for i, column in enumerate(self.headers[name]):
            header.write(i, self.headers[name][i])

    def output(self):
        """
        Create full path for excel file to save parsed translations strings.
        Returns:
            unicode: full path for excel file to save parsed translations strings.
        """

        path, src = os.path.split(self.src)
        src, ext = os.path.splitext(src)

        return os.path.join(path, "{src}.xls".format(**{"src": src, }))

    def strings(self):
        """
        Write strings sheet.
        """

        sheet = self.result.add_sheet("strings")
        self.header(sheet, "strings")

        n_row = 1  # row number

        for entry in self.po:
            row = sheet.row(n_row)
            row.write(0, entry.msgid)
            row.write(1, entry.msgstr)
            n_row += 1
            sheet.flush_row_data()

    def metadata(self):
        """
        Write metadata sheet.
        """

        sheet = self.result.add_sheet("metadata")
        self.header(sheet, "metadata")

        n_row = 1  # row number

        for k in self.po.metadata:
            row = sheet.row(n_row)
            row.write(0, k)
            row.write(1, self.po.metadata[k])
            n_row += 1
            sheet.flush_row_data()

    def convert(self, *args, **kwargs):
        """
        Yes it is, thanks captain.
        """

        self.strings()
        self.metadata()

        # save file
        self.result.save(self.output())



# -*- coding: utf-8 -*-

# django-po2xls
# po2xls/apps.py

from __future__ import unicode_literals

from django.apps import AppConfig


__all__ = [
    "Config",
]


class Config(AppConfig):

    name = "po2xls"
    verbose_name = ".po to .xls"



#!/usr/bin/env python
# -*- coding: utf-8 -*-

# django-po2xls
# setup.py

from setuptools import (
    setup,
    find_packages,
)


# metadata
VERSION = (0, 4, 0)
__version__ = ".".join(map(str, VERSION))
setup(
    name="django-po2xls",
    version=__version__,
    packages=find_packages(),
    install_requires=[
        "Django",
        "django-rosetta==0.7.13",
        "polib==1.0.8",
        "xlwt==1.2.0",
    ],
    author="Alexei Andrushievich",
    author_email="vint21h@vint21h.pp.ua",
    description="Convert gettext .po files to .xls",
    license="GPLv3 or later",
    url="https://github.com/vint21h/django-po2xls/",
    download_url="https://github.com/vint21h/django-po2xls/archive/{version}.tar.gz".format(version=__version__),
    zip_safe=False,
    include_package_data=True,
    classifiers=[
        "Environment :: Console",
        "Environment :: Plugins",
        "License :: OSI Approved :: GNU General Public License v3 or later (GPLv3+)",
        "Operating System :: Unix",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3",
        "Topic :: Utilities",
        "Framework :: Django :: 1.8",
        "Framework :: Django :: 1.9",
        "Framework :: Django :: 1.10",
        "Framework :: Django :: 1.11",
    ]
)
